<?
/*
<!--
-------------------------------------------------------------------------------

    Arquivo : bibliotecas/usuarios.inc

    TelEduc - Ambiente de Ensino-Aprendizagem a Distncia
    Copyright (C) 2001  NIED - Unicamp

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License version 2 as
    published by the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    You could contact us through the following addresses:

    Nied - Ncleo de Informtica Aplicada  Educao
    Unicamp - Universidade Estadual de Campinas
    Cidade Universitria "Zeferino Vaz"
    Bloco V da Reitoria - 2o. Piso
    CEP:13083-970 Campinas - SP - Brasil

    http://www.nied.unicamp.br
    nied@unicamp.br

------------------------------------------------------------------------------
-->
*/

/*==========================================================
  ARQUIVO : bibliotecas/usuarios.inc
  ========================================================== */

/* *********************************************************************
   RetornaStatusUsuario - Retorna o status do Usurio
   Entradas: $sock - Socket da base de dados (retorno do Conectar)
             BASE DO CURSO         
             $cod_curso - Cdigo do curso 
             $cod_usuario - Cdigo do usurio a buscar a informao                        
   Saida: I - aluno invlido ou inexistente
          a - Aluno inscrito
          r - Aluno rejeitado
          A - Aluno Aceito
          F - Formador
          V - Visitante
   OBS.: Esta funo retorna o status real do usurio. 
         Checar se no  um formador querendo ter a viso do aluno com
         $visao_aluno_s==true
*/
function RetornaStatusUsuario($sock,$cod_curso,$cod_usuario)
{
  /* Se Visitante, retorna como Visitante */
  if ($cod_usuario==-2)
    return ("V");
  /* Se administrador, retorna como Formador */
  if ($cod_usuario==-1)
    return ("F");
  $query="select tipo_usuario from Usuario where cod_usuario=".$cod_usuario;
  $res=Enviar($sock,$query);
  if (RetornaNumLinhas($res)>0)
  {
    $linha=RetornaLinha($res);   
    return ($linha[0]);
  }
  else 
  {
    return ("I");
  }
}

/* *********************************************************************
   VerificaAcessoAoCurso- Barra usurios que ainda no foram aceitos ou 
                          que foram rejeitados de acessar a pgina
   Entradas: $sock - Socket da base de dados (retorno do Conectar)
                     BASE EXTERNA
             $cod_curso - Cdigo do curso 
             $cod_usuario - Cdigo do usurio a buscar a informao                        
   Saida: Envia mensagem de acesso negado e interrompe a execuo, caso 
          aluno seja a ou r
*/
function VerificaAcessoAoCurso($sock,$cod_curso,$cod_usuario)
{
  $status=RetornaStatusUsuario($sock,$cod_curso,$cod_usuario);

  if ($status=="a" || $status=="r" || $status=="I")
  {
    /* 13 - Acesso negado */
    $mensagem ="<b>".RetornaFrase($sock,13,-2)."</b><br><br>";
    if ($status=="a")
      /* 14 - Sua inscrio ainda no foi avaliada. Um e-mail lhe ser enviado quando a avaliao de sua inscrio for feita. */
      $mensagem.=RetornaFrase($sock,14,-2);
    else if ($status=="r")
      /* 15 - Sua inscrio no foi aceita. Voc no tem acesso a esse curso. */
      $mensagem.=RetornaFrase($sock,15,-2);
    else
      /* 16 - Usurio inexistente ou invlido.*/
      $mensagem.=RetornaFrase($sock,16,-2);
    /* 23 - Voltar */
    $mensagem.="<br><br><a href=# onclick=history.go(-1);>".RetornaFrase($sock,23,-1)."</a>";
    die ($mensagem);
  }
}

/* *********************************************************************
   VerificaAcessoAFerramenta - Barra usurios de entrar em ferramentas desabilitadas
   Entradas: $sock - Socket da base de dados (retorno do Conectar)
                     BASE EXTERNA
             $cod_curso - Cdigo do curso
             $cod_usuario - Cdigo do usurio a buscar a informao
             $cod_ferramenta - Codigo da ferramenta
   Saida: Envia mensagem de acesso negado e interrompe a execuo, caso a ferramenta 
          esteja desabilitada (checa status de aluno) 
*/
function VerificaAcessoAFerramenta($sock,$cod_curso,$cod_usuario,$cod_ferramenta)
{
  $status=RetornaStatusUsuario($sock,$cod_curso,$cod_usuario);
  $query="select status from Curso_ferramentas where cod_ferramenta=".$cod_ferramenta;
  $res=Enviar($sock,$query);
  $linha=RetornaLinha($res);
  if ($linha['status']=='D' || ($linha['status']=='F' && $status=='A'))
  {
    // 59 - Ferramenta desabilitada
    die("<b>RetornaFrase($sock,59,-1)</b>");
  }
}


/* *********************************************************************
   EFormador - Retorna true se usurio for formador
   Entradas: $sock - Socket da base de dados (retorno do Conectar)
             $cod_curso - Cdigo do curso 
             $cod_usuario - Cdigo do usurio a buscar a informao                        
   Saida: true se  formador e este no esta com visao de aluno, false caso contrrio 
   OBS.: O coordenador aparece tambm como formador
*/
function EFormador($sock,$cod_curso,$cod_usuario)
{
  global $visao_aluno_s;
  $estado=RetornaStatusUsuario($sock,$cod_curso,$cod_usuario);
  if ($estado=="F")
  {
    if ($visao_aluno_s)
      return false; 
    return true;
  }
  else
    return false;
}


/* *********************************************************************
   EFormadorMesmo - Retorna true se usurio for formador
   Entradas: $sock - Socket da base de dados (retorno do Conectar)
             $cod_curso - Cdigo do curso
             $cod_usuario - Cdigo do usurio a buscar a informao

   Saida: true se  formador, false caso contrrio
   OBS.: O coordenador aparece tambm como formador
*/
function EFormadorMesmo($sock,$cod_curso,$cod_usuario)
{
  $estado=RetornaStatusUsuario($sock,$cod_curso,$cod_usuario);
  if ($estado=="F")
    return true;
  else
    return false;
}


/* *********************************************************************
   EAluno - Retorna true se usurio for aluno
   Entradas: $sock - Socket da base de dados (retorno do Conectar)
             $cod_curso - Cdigo do curso 
             $cod_usuario - Cdigo do usurio a buscar a informao                        
   Saida: true se  aluno, false caso contrrio 
*/
function EAluno($sock,$cod_curso,$cod_usuario)
{
  global $visao_aluno_s;
  $estado=RetornaStatusUsuario($sock,$cod_curso,$cod_usuario);
  if ($estado=="A")
    return true;
  else
  {
    if ($estado=="F" && $visao_aluno_s)
      return true;
    return false;
  }
}

/* *********************************************************************
   EAlunoMesmo - Retorna true se usurio for aluno
   Entradas: $sock - Socket da base de dados (retorno do Conectar)
             $cod_curso - Cdigo do curso
             $cod_usuario - Cdigo do usurio a buscar a informao
   Saida: true se  aluno, false caso contrrio
*/
function EAlunoMesmo($sock,$cod_curso,$cod_usuario)
{
  $estado=RetornaStatusUsuario($sock,$cod_curso,$cod_usuario);
  if ($estado=="A")
    return true;
  else
    return false;
}


/* *********************************************************************
   ECoordenador - Retorna true se usurio for coordenador
   Entradas: $sock - Socket da base de dados (retorno do Conectar)
             $cod_curso - Cdigo do curso 
             $cod_usuario - Cdigo do usurio a buscar a informao                        
   Saida: true se  coordenador, false caso contrrio 
*/
function ECoordenador($sock,$cod_curso,$cod_usuario)
{
  $estado=RetornaStatusUsuario($sock,$cod_curso,$cod_usuario);
  if ($estado=="F")
  {
    $query="select cod_coordenador from Cursos where cod_curso=".$cod_curso;
		$res=Enviar($sock,$query);
    $linha=RetornaLinha($res);
    if ($linha[0]==$cod_usuario)
      return true;
  }
  return false;
}


/* *********************************************************************
   EVisitante - Retorna true se visitante for aluno
   Entradas: $sock - Socket da base de dados (retorno do Conectar)
             $cod_curso - Cdigo do curso 
             $cod_usuario - Cdigo do usurio a buscar a informao                        
   Saida: true se  aluno, false caso contrrio 
*/
function EVisitante($sock,$cod_curso,$cod_usuario)
{
  $estado=RetornaStatusUsuario($sock,$cod_curso,$cod_usuario);
  if ($estado=="V")
    return true;
  else
    return false;
}

/* *********************************************************************
   MarcaAcesso - Marca o acesso a determinada ferramenta pelo aluno
   Entradas: $sock - sock aberto para a base do curso (Conectar($cod_curso))
             $cod_usuario - Cdigo do usurio a buscar a informao                        
             $cod_ferramenta - Cdigo da ferramenta. "" se Entrada no 
                               TelEduc
   Saida: nenhuma
*/
function MarcaAcesso($sock,$cod_usuario,$cod_ferramenta)
{
  if ($cod_usuario<0)
    return;
  $agora=time();
  if ($cod_ferramenta!="")
  {
    $query="select cod_ferramenta from Curso_acessos where cod_usuario=".$cod_usuario." order by data desc limit 1";
    $res=Enviar($sock,$query);
    $linha=RetornaLinha($res);
    if ($linha['cod_ferramenta']!=$cod_ferramenta)
    {
      $query="insert into Curso_acessos values (".$cod_usuario.",".$agora.",".$cod_ferramenta.")";
      Enviar($sock,$query);
    }
  }
  else
  {
    $query="select cod_ferramenta from Curso_acessos where cod_usuario=".$cod_usuario." order by data desc limit 1";
    $res=Enviar($sock,$query);
    $num=RetornaNumLinhas($res);
    $linha=RetornaLinha($res);
    if ($linha['cod_ferramenta']!="" || $num==0)
    {
      $query="insert into Curso_acessos (cod_usuario,data) values (".$cod_usuario.",".$agora.")";
      Enviar($sock,$query);
    }
  }
}

/* *********************************************************************
   UltimoAcesso - Retorna o timestamp do ltimo acesso a determinada 
                   ferramenta
   Entradas: $sock - sock aberto para a base do curso (Conectar($cod_curso))
             $cod_usuario - Cdigo do usurio a buscar a informao                        
             $cod_ferramenta - Cdigo da ferramenta. "" se Entrada no 
                               TelEduc
   Saida: timestamp do ltimo acesso
*/
function UltimoAcesso($sock,$cod_usuario,$cod_ferramenta)
{
  if ($cod_usuario<0)
    return time();
  if ($cod_ferramenta!="")
    $query="select data from Curso_acessos where cod_usuario=".$cod_usuario." and cod_ferramenta=".$cod_ferramenta." order by data desc limit 1";
  else
    $query="select data from Curso_acessos where cod_usuario=".$cod_usuario." and cod_ferramenta is NULL order by data desc limit 1";
  $res=Enviar($sock,$query);
  if (RetornaNumLinhas($res)>0)
  {
    $linha=RetornaLinha($res);
    return $linha[0];
  }
  else
    return 0;
}

/* *********************************************************************
   PenultimoAcesso - Retorna o timestamp do penltimo acesso a determinada 
                   ferramenta
   Entradas: $sock - sock aberto para a base do curso (Conectar($cod_curso))
             $cod_usuario - Cdigo do usurio a buscar a informao                        
             $cod_ferramenta - Cdigo da ferramenta. "" se Entrada no 
                               TelEduc
   Saida: timestamp do ltimo acesso
*/
function PenultimoAcesso($sock,$cod_usuario,$cod_ferramenta)
{
  if ($cod_usuario<0)
    return time();
  if ($cod_ferramenta!="")
    $query="select data from Curso_acessos where cod_usuario=".$cod_usuario." and cod_ferramenta=".$cod_ferramenta." order by data desc limit 2";
  else
    $query="select data from Curso_acessos where cod_usuario=".$cod_usuario." and cod_ferramenta is NULL order by data desc limit 2";
  $res=Enviar($sock,$query);
  if (RetornaNumLinhas($res)>1)
  {
    $linha=RetornaLinha($res);
    $linha=RetornaLinha($res);
    return $linha[0];
  }
  else
    return 0;
}

/* *********************************************************************
   AjustaNome - Ajusta o nome do usuario em relao as maiusculas e minusculas
   Entradas: $nome_usuario
   Saida: nome com maiusculas e minsculas corrigidas
*/
function AjustaNome($nome_usuario)
{
  $tmp=explode(" ",$nome_usuario);
  if (count($tmp)>0)
  {
    foreach($tmp as $cod => $nome)
    {
      $tmp[$cod]=strtr($nome,"ABCDEFGHIJLKMNOPQRSTUVWXYZ","abcdefghijlkmnopqrstuvwxyz");
      $primeira=substr($tmp[$cod],0,1);
      $resto=substr($tmp[$cod],1);
      $primeira=strtr($primeira,"abcdefghijlkmnopqrstuvwxyz","ABCDEFGHIJLKMNOPQRSTUVWXYZ");
      $tmp[$cod]=$primeira.$resto; 
    }
    $saida=implode(" ",$tmp);
  } 
  return $saida;
}


/* *********************************************************************
   NomeUsuario - Retorna o nome do usuario
   Entradas: $sock - sock aberto para a base do curso (Conectar($cod_curso))
             $cod_usuario - Cdigo do usurio a buscar a informao                        
   Saida: nome
*/
function NomeUsuario($sock,$cod_usuario)
{
  if ($cod_usuario==-2)
    return ("Visitante");
  $query="select nome from Usuario where cod_usuario=".$cod_usuario;
  $res=Enviar($sock,$query);
  $linha=RetornaLinha($res);
  $nome_usuario=$linha[0];
  if ($nome_usuario != AjustaNome($nome_usuario))
  {
    $nome_usuario=AjustaNome($nome_usuario);
    $query="update Usuario set nome='".$nome_usuario."' where cod_usuario=".$cod_usuario;
    Enviar($sock,$query);
  }

  return ($nome_usuario);
}

/* *********************************************************************
   AtualizaFerramentasNova - Atualiza data de novidades
   Entradas: $sock - sock aberto para a base do curso (Conectar($cod_curso))
             $cod_ferramenta - Cdigo da ferramenta 
             $tipo_usuario - T todos e F formadores
   Saida: nenhuma
*/
function AtualizaFerramentasNova($sock,$cod_ferramenta,$tipo_usuario)
{
  $query="update Ferramentas_nova set data=".time()." where cod_ferramenta=".$cod_ferramenta;
  if ($tipo_usuario=="F")
    $query.=" and tipo_compartilhamento='F'";
  Enviar($sock,$query);
}

/* *********************************************************************
   HaDadosFaltando - Retorna true se houver algum dado do aluno/formador faltando
   Entradas: $sock - sock aberto para a base do curso (Conectar($cod_curso))
             $cod_usuario - Cdigo do usurio a buscar a informao
   Saida: true ou false
*/
function HaDadosFaltando($sock,$cod_usuario)
{
  if ($cod_usuario<0)
    return false;
  $query="select tipo_usuario,rg,data_nasc,sexo,endereco,cidade,estado,pais from Usuario where cod_usuario=".$cod_usuario;
  $res=Enviar($sock,$query);
  $linha=RetornaLinha($res);
  if ($linha['tipo_usuario']=='F' && $linha['rg']=="")
    return true;
  if ($linha['data_nasc']=="" || $linha['sexo']=="" || $linha['endereco']=="" || $linha['cidade']=="" || $linha['estado']=="" || $linha['pais']=="")
    return true;
  return false;
  
}

/* *********************************************************************
   EFormadorComVisaoDeAluno - Retorna true se usurio for formador com visao de aluno
   Entradas: $sock - Socket da base de dados (retorno do Conectar)
             $cod_curso - Cdigo do curso
             $cod_usuario - Cdigo do usurio a buscar a informao
   Saida: true se  formador e este esta com visao de aluno, false caso contrrio
   OBS.: O coordenador aparece tambm como formador
*/
function EFormadorComVisaoDeAluno($sock,$cod_curso,$cod_usuario)
{
  global $visao_aluno_s;
  $estado=RetornaStatusUsuario($sock,$cod_curso,$cod_usuario);
  if ($estado=="F")
  {
    if ($visao_aluno_s)
      return true;
    return false;
  }
  else
    return false;
}


/* *********************************************************************
   RetornaLinguaUsuario - Retorna o codigo da lingua selecionada pelo usuario
   Entradas: $sock - Socket da base de dados (retorno do Conectar)
             $cod_usuario - Cdigo do usurio a buscar a informao
   Saida: Codigo da Lingua selecionada pelo usuario 
*/
function RetornaLinguaUsuario($sock,$cod_usuario)
{
  global $cod_lingua_s;
  $query="select cod_lingua from Usuario where cod_usuario=".$cod_usuario;
  $res=Enviar($sock,$query);
  if (RetornaNumLinhas($res)>0)
  {
    $linha=RetornaLinha($res);
    return ($linha[0]);
  }
  else
  {
    // Se no tem registro (?!?) retorna a lingua atual
    return ($cod_lingua_s);
  }
}




?>
